# -*- coding: utf-8; tab-width: 4; indent-tabs-mode: nil -*-
#
# Copyright (C) 2009 - Jeremy AustinBardo <ausimage@ubuntu.com>
# Copyright (C) 2006 - Florian Ludwig <dino@phidev.info>;
#   Franz Pletz <fpletz@franz-pletz.org>
#
# Apt-zeroconf is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Apt-zeroconf is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with apt-zeroconf; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""
Traffic Tracker Module for apt-zeroconf.

@requires: aptzeroconf.util.synchronized
@requires: threading
"""
import threading
from aptzeroconf.util import synchronized

class Counter:
    """
    Counter to keep running a total.
    @requires: aptzeroconf.util.synchronized
    """
    lock = threading.Lock()

    def __init__(self):
        """
        Set counter inital value
        """
        self.data = 0

    @synchronized(lock)
    def __str__(self):
        """
        Return a string of current total
        @return: Current Total
        @rtype: basestring
        """
        return str(float(self.data) / 1024)

    @synchronized(lock)
    def add(self, i):
        """
        Add a sum value to current counter value.
        """
        self.data += i

#    @synchronized(lock)
#    def get(self):
#        return self.data

lan_recv = Counter()
www_recv = Counter()
