##########   FoKoN 9.10   ###########\
# Intégration de poste Ubuntu 9.10   #
# dans un domaine Active Directory   #
# géré par IACA.                     #
#------------------------------------#
# Script : common.sh                 #
# Vérifications nécessaires pour la  #
# bonne exécution de chaque script.  #
# Variables communes.                #      
#------------------------------------#
# Auteur : Claude CLERC              #
# <claude.clerc@ac-aix-marseille.fr> #
# Site : http://www.fokon.org        #
# Licence : CeCILL - GPL 2.0         #
#####################################/
export VERSION_UBUNTU="9.10"
export VERSION_FOKON="0.20"
export NOM_UBUNTU="karmic"

source /etc/lsb-release
export DISTRIB_ID
export DISTRIB_RELEASE
export DISTRIB_CODENAME
export DISTRIB_DESCRIPTION

#export RACINE="/home/administrateur/Bureau/FoKoN/racine"
export RACINE="/"

# Le script doit être lancé avec sudo.
[ "$USER" = "root" ] || {
	zenity --error --text="Vous devez lancer ce programme avec des droits d'administrateur.

Pour cela utiliser : <b>sudo $0</b>" --window-icon="/usr/share/icons/Human/24x24/status/gtk-dialog-error.png"
	exit 1
}

# Vérification du bon numéro de version d'Ubuntu : 
UBVERS=`cat /etc/issue | grep Ubuntu | awk '{print $2}'`
[ "v${UBVERS}" = "v${VERSION_UBUNTU}" ] || {
	zenity --error --text="Ce script n'est pas adapté à votre version d'Ubuntu. Il est prévu pour la version ${VERSION_UBUNTU} alors que votre version est la ${UBVERS}." --window-icon="/usr/share/icons/Human/24x24/status/gtk-dialog-error.png"
	exit 1
}

# Dossier de sauvegarde
export DIR_SVG="/var/local/SYS_ORIG_before_FoKoN"
[ -d ${DIR_SVG} ] || {
	# Il n'existe pas, on le crée, on lui donne les bon droits et les bons propriétaire et groupe.
	mkdir -p ${DIR_SVG}
	chmod 750 ${DIR_SVG}
	chown root:admin ${DIR_SVG}
}

function transforme() {
	# Chacun des fichiers de la liste_f, pris dans TEMPLATES, est lu ligne à ligne.
	# Chaque ligne est transformée en remplaçant les noms de variables par leur contenu,
	# puis insérée dans le même fichier à partir de RACINES.
	for f in ${liste_f}; do {
		DIR_f=`dirname ${RACINE}/$f`
		[ -f  ${RACINE}/$f ] && {
			# Le fichier existe dans RACINE.
			[ -f  ${DIR_SVG}/${RACINE}/${f}_ORIG ] || {
				# Sauvegarde du fichier f original (avant lancement de FoKoN) dans f_ORIG, dans le dossier
				# ${DIR_SVG}.
				#DIR_f=`dirname ${RACINE}/$f`
				mkdir -p ${DIR_SVG}/${DIR_f}
				cp -a ${RACINE}/$f ${DIR_SVG}/${RACINE}/${f}_ORIG
			}
			
			# Sauvegarde du fichier f actuel dans f_LAST, dans un sous dossier
			# /FoKoN/SYS_ORIG du HOME de l'admin qui lance ce script.
			#DIR_f=`dirname ${RACINE}/$f`
			#mkdir -p /var/FoKoN/SYS_ORIG/${DIR_f}	# FIXME : Normalement inutile ? Dossier déjà créé pour f_ORIG.
			cp -a ${RACINE}/$f ${DIR_SVG}/${RACINE}/${f}_LAST
			
			# Suppression du fichier f actuel.
			rm -f ${RACINE}/$f
		}
		# Création du fichier f.
		#DIR_f=`dirname ${RACINE}/$f`
		[ -d ${DIR_f} ] || mkdir -p ${DIR_f}
		touch ${RACINE}/$f
		./transforme.pl $f
		# Le script perl ci-dessus remplace très avantageusement les lignes suivantes 
		#(qui nécessitaient une protection de certains caractères par \\) :
		# Lecture ligne à ligne du fichier-template f
		#while read l; do {
		#	[ "x$l" = "x" ] && echo $l >> ${RACINE}/$f
		#	[ "x$l" = "x" ] || {
		#		[ "x${l:0:1}" = "x#" ] && echo $l >> ${RACINE}/$f
		#		[ "x${l:0:1}" = "x#" ] || eval echo $l >> ${RACINE}/$f
		#	}
		#}; done < ${TEMPLATES}/$f
	}; done
}

function copie() {
	# Chacun des fichiers de la liste_f, pris dans TEMPLATES, est copié dans RACINE sans aucune transformation.
	for f in ${liste_f}; do {
		DIR_f=`dirname ${RACINE}/$f`
		[ -f  ${RACINE}/$f ] && {
			# Le fichier existe dans RACINE.
			[ -f  ${DIR_SVG}/${RACINE}/${f}_ORIG ] || {
				# Sauvegarde du fichier f original (avant lancement de FoKoN) dans f_ORIG, dans le dossier
				# ${DIR_SVG}.
				#DIR_f=`dirname ${RACINE}/$f`
				mkdir -p ${DIR_SVG}/${DIR_f}
				cp -a ${RACINE}/$f ${DIR_SVG}/${RACINE}/${f}_ORIG
			}
			
			# Sauvegarde du fichier f actuel dans f_LAST, dans un sous dossier
			# /FoKoN/SYS_ORIG du HOME de l'admin qui lance ce script.
			#DIR_f=`dirname ${RACINE}/$f`
			#mkdir -p /var/FoKoN/SYS_ORIG/${DIR_f}	# FIXME : Normalement inutile ? Dossier déjà créé pour f_ORIG.
			cp -a ${RACINE}/$f ${DIR_SVG}/${RACINE}/${f}_LAST
			
			# Suppression du fichier f actuel.
			rm -f ${RACINE}/$f
		}
		# Copie du fichier f.
		#DIR_f=`dirname ${RACINE}/$f`
		[ -d ${DIR_f} ] || mkdir -p ${DIR_f}
		cp ${TEMPLATES}/$f ${RACINE}/$f
		touch ${RACINE}/$f
	}; done
}
